Crate shuttle_engine

Crate shuttle_engine 

Re-exports

pub use config::Config;
pub use config::ContinuationFunctionBehavior;
pub use config::FailurePersistence;
pub use config::MaxSteps;
pub use config::UngracefulShutdownConfig;
pub use config::UNGRACEFUL_SHUTDOWN_CONFIG;
pub use runtime::runner::PortfolioRunner;
pub use runtime::runner::Runner;
pub use sync_types::ResourceSignature;
pub use sync_types::ResourceType;

Modules

annotations
Annotated schedules. When an execution is scheduled using an AnnotationScheduler, Shuttle will produce a file that contains additional information about the execution, such as the kind of step that was taken (was a task created, were permits acquired from a semaphore, etc) as well as the task’s vector clocks and thus any causal dependence between the tasks. The resulting file can be visualized using the Shuttle Explorer IDE extension.
config
current
Information about the current thread and current Shuttle execution.
future
hint
Shuttle’s implementation of std::hint.
runtime
scheduler
Core scheduling types: the Scheduler trait, Schedule, and supporting data structures.
sync_types
thread_support

Constants

ANNOTATION_FILE
Used in the annotation scheduler to specify where to write the annotations.
CAPTURE_BACKTRACE
If this environment variable is set, then Shuttle will capture the backtrace of each task and display the backtraces in the panic message. Capturing backtraces is quite expensive, so this should only be set when debugging a failing test.
SILENCE_WARNINGS
If this is set, then warnings about Shuttle’s modelling of weak memory and differences between Shuttle’s version of LazyStatic and the regular version of LazyStatic will not be emitted.

Functions

backtrace_enabled
seed_from_env
silence_warnings