Module annotations

Module annotations 

Annotated schedules. When an execution is scheduled using an AnnotationScheduler, Shuttle will produce a file that contains additional information about the execution, such as the kind of step that was taken (was a task created, were permits acquired from a semaphore, etc) as well as the task’s vector clocks and thus any causal dependence between the tasks. The resulting file can be visualized using the Shuttle Explorer IDE extension.

Structs

ObjectId

Constants

DUMMY_OBJECT_ID

Traits

WithName
Trait to record information about shared objects, such as their name and type. See implementation in crate::future::batch_semaphore::BatchSemaphore, which actually records the name into the schedule, other types should forward calls into their underlying primitive, as in shuttle::sync::Mutex.

Functions

record_name_for_object
record_name_for_task
record_random
record_schedule
record_semaphore_acquire_blocked
record_semaphore_acquire_fast
record_semaphore_acquire_unblocked
record_semaphore_closed
record_semaphore_created
record_semaphore_release
record_semaphore_try_acquire
record_task_created
record_task_terminated
record_tick
start_annotations
stop_annotations