Module config

Module config 

Structs

Config
Configuration parameters for Shuttle
UngracefulShutdownConfig
The config to define how to handle ungraceful shutdowns, ie. when the test panics.

Enums

ContinuationFunctionBehavior
What to do with what the unfinished tasks of a failed execution leave behind: the functions of the tasks that never ran, and the futures of the future tasks that are waiting to be polled. The stacks of a failed execution’s other unfinished tasks are always leaked, and its task-local values and statics are always dropped. Panics while dropping any of them are ignored, so that the failure is what gets reported.
FailurePersistence
Specifies how to persist schedules when a Shuttle test fails
MaxSteps
Specifies an upper bound on the number of steps a single iteration of a Shuttle test can take, and how to react when the bound is reached.

Constants

UNGRACEFUL_SHUTDOWN_CONFIG