remove_label_for_task

Function remove_label_for_task 

pub fn remove_label_for_task<T: Clone + Debug + 'static>(
    task_id: TaskId,
) -> Option<T>
Remove a label of the given type for the specified task, returning the old label for the type, if any