set_label_for_task

Function set_label_for_task 

pub fn set_label_for_task<T: Clone + Debug + 'static>(
    task_id: TaskId,
    value: T,
) -> Option<T>
Add the given label to the specified task, returning the old label for the type, if any