Module future

Module future 

Modules

batch_semaphore
A counting semaphore supporting both async and sync operations.

Functions

block_on
Run a future to completion on the current thread.
yield_now
Yields execution back to the scheduler.