Module batch_semaphore

Module batch_semaphore 

A counting semaphore supporting both async and sync operations.

Structs

Acquire
The future that results from async calls to acquire*. Callers must await on this future to obtain the necessary permits.
AcquireError
Error returned from the BatchSemaphore::acquire function.
BatchSemaphore
Counting semaphore

Enums

Fairness
Fairness mode for the semaphore. Determines which threads are woken when permits are released.
TryAcquireError
Error returned from the BatchSemaphore::try_acquire function.