pub fn spin_loop()Expand description
Emits a machine instruction to signal the processor that it is running in a busy-wait spin-loop (“spin lock”).
pub fn spin_loop()Emits a machine instruction to signal the processor that it is running in a busy-wait spin-loop (“spin lock”).