pub struct Execution { /* private fields */ }Expand description
An Execution encapsulates a single run of a function under test against a chosen scheduler.
Its only useful method is Execution::run, which executes the function to completion.
The key thing that an Execution manages is the ExecutionState, which contains all the
mutable state a test’s tasks might need access to during execution (to block/unblock tasks,
spawn new tasks, etc). The Execution makes this state available through the EXECUTION_STATE
static variable, but clients get access to it by calling ExecutionState::with.
Implementations
Sourceimpl Execution
impl Execution
Sourcepub fn run<F>(self, config: &Config, f: F, caller: &'static Location<'static>)
pub fn run<F>(self, config: &Config, f: F, caller: &'static Location<'static>)
Run a function to be tested, taking control of scheduling it and any tasks it might spawn.
This function runs until f and all tasks spawned by f have terminated, or until the
scheduler returns None, indicating the execution should not be explored any further.