Module runner

Module runner 

Structs

PortfolioRunner
A PortfolioRunner is the same as a Runner, except that it can run multiple different schedulers (a “portfolio” of schedulers) in parallel. If any of the schedulers finds a failing execution of the test, the entire run fails.
Runner
A Runner is the entry-point for testing concurrent code.