pub struct ChildLabelFn(pub Arc<dyn Fn(TaskId, &mut Labels) + 'static>);Expand description
A special label that can be used to set labels for a task when it is spawned.
By default, when a task or thread T is spawned, it inherits all labels from its parent.
It’s often useful to modify or add new Labels to T. One approach is to put label changes
at the beginning of the closure that is passed to spawn, but this approach has the drawback
that the changes are applied only when T is first selected for execution, and the closure
is invoked. To overcome this drawback, we introduce the ChildLabelFn label. If a parent
task or thread has a ChildLabelFn set when it spawns a new child task or thread, the
child’s label set at spawn time will be modified by applying the function inside the ChildLabelFn.
Example
The following example shows how a ChildLabelFn can be used to set up names for the next child(ren)
that will be spawned by a parent task (see shuttle/tests/basic/labels.rs for runnable versions).
// In the parent, set up a `ChildLabelFn` that assigns a name to the child task
shuttle::check_dfs(|| {
set_label_for_task(me(), ChildLabelFn(Arc::new(|_task_id, labels| { labels.insert(TaskName::from("ChildTask")); })));
shuttle::thread::spawn(|| {
assert_eq!(get_name_for_task(me()).unwrap(), TaskName::from("ChildTask")); // child task already has the name
// ... rest of child
}).join().unwrap();
}, None);Tuple Fields
0: Arc<dyn Fn(TaskId, &mut Labels) + 'static>Trait Implementations
Sourceimpl Clone for ChildLabelFn
impl Clone for ChildLabelFn
Sourcefn clone(&self) -> ChildLabelFn
fn clone(&self) -> ChildLabelFn
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for ChildLabelFn
impl !Send for ChildLabelFn
impl !Sync for ChildLabelFn
impl !UnwindSafe for ChildLabelFn
impl Freeze for ChildLabelFn
impl Unpin for ChildLabelFn
impl UnsafeUnpin for ChildLabelFn