TaskSignature

Struct TaskSignature 

pub struct TaskSignature { /* private fields */ }
A task signature is an identifier that is intended to be mostly stable across executions and allow for categorization of tasks according to how they were created. It provides two levels of granularity: static (compile-time) spawn location and dynamic (run-time) context where that spawn location was reached. The static spawn location and signature are each represented by a u64 so that the details of how they are computed can be non-breaking changes in the future. Hashes are all pre-computed for fast checking of equality of signatures at runtime.

Implementations

Source

impl TaskSignature

pub fn new_parentless( spawn_call_site: &'static Location<'static>, ) -> TaskSignature

pub fn new_child(&mut self, spawn_call_site: &'static Location<'static>) -> Self

pub fn new_resource(&mut self, resource_type: ResourceType) -> ResourceSignature

pub fn static_create_location_hash(&self) -> u64

Hash of the static location within the source code where the task was spawned

pub fn signature_hash(&self) -> u64

Combined signature of the static location and dynamic context context where the task was spawned.

pub fn parent_signature_hash(&self) -> u64

Signature hash of the parent of this task