pub trait Taggable: Debug { }👎Deprecated
Taggable is a marker trait which types implementing Tag have to implement.
It exists since we both want to provide a blanket implementation of as_any, and have users
opt in to a type being able to be used as a tag. If we did not have this trait, then Tag
would be automatically implemented for most types (as most types are Debug + Any), which
opens up for accidentally using a type which was not intended to be used as a tag as a tag.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".