pub struct Continuation {
pub yielder: *const Yielder<ContinuationInput, ContinuationOutput>,
/* private fields */
}Expand description
A continuation is a green thread that can be resumed and yielded at will. We use it to execute a “thread” from within a Future.
For efficiency, we reuse continuations. The continuation can be provided a new function
to run via initialize. A continuation is only reusable if the previous function it was
executing completed.
Fields
yielder: *const Yielder<ContinuationInput, ContinuationOutput>Implementations
Sourceimpl Continuation
impl Continuation
pub fn new(stack_size: usize) -> Self
Sourcepub fn initialize(&mut self, fun: Box<dyn FnOnce()>)
pub fn initialize(&mut self, fun: Box<dyn FnOnce()>)
Provide a new function for the continuation to execute. The continuation must be in reusable state.
Sourcepub fn resume(&mut self) -> bool
pub fn resume(&mut self) -> bool
Resume the continuation, and returns true if the function it was executing has finished.
Sourcepub fn cancel(&mut self) -> bool
pub fn cancel(&mut self) -> bool
Resume the continuation to cancel its function, and return true if the function has
finished, like resume. This is how execution teardown drops a task that is unfinished at
the end of an execution, on the task’s own stack (see ExecutionState::tear_down). A
function that never ran is dropped. A function suspended between polls of a future (see
switch_between_polls) drops the future and returns. Only these two are cancelled: any other
suspended function is in the middle of user code, which only unwinding its stack can stop.