Re-exports
pub use random::RandomDataSource;
Modules
Traits
- Data
Source - A
DataSourceis an oracle for generating non-deterministic data to return to a task that asks for random values.
pub use random::RandomDataSource;DataSource is an oracle for generating non-deterministic data to return to a task that asks
for random values.