Module random

Module random 

Structs

RandomDataSource
A RandomDataSource generates non-deterministic data from a random number generator, and arranges to re-seed that RNG on each new execution to enable deterministic replay.