Module sync_types

Module sync_types 

Structs

ResourceSignature

Enums

ResourceType
A stable signature for identifying resources in Shuttle tests. This is used internally to track and differentiate between different resource instances across shuttle iterations. This signature hash is not guaranteed to be unique (two different resources may have the same hash). In particular, resources which provide const constructors cannot provide any runtime context to their signatures, so any two resources created at the same source location will collide.