pub struct ResourceSignature { /* private fields */ }Implementations
Sourceimpl ResourceSignature
impl ResourceSignature
pub const fn new_const(resource_type: ResourceType) -> Self
pub const fn new( resource_type: ResourceType, static_create_location: &'static Location<'static>, parent_task_signature: u64, create_location_counter: u32, ) -> Self
Sourcepub fn static_create_location_hash(&self) -> u64
pub fn static_create_location_hash(&self) -> u64
Hash of the static location within the source code where the task was spawned
Sourcepub fn signature_hash(&self) -> u64
pub fn signature_hash(&self) -> u64
Combined signature of the static location and dynamic context context where the task was spawned.