Annotated schedules. When an execution is scheduled using an
AnnotationScheduler, Shuttle will produce a file that contains
additional information about the execution, such as the kind of step that
was taken (was a task created, were permits acquired from a semaphore, etc)
as well as the task’s vector clocks and thus any causal dependence between
the tasks. The resulting file can be visualized using the Shuttle Explorer
IDE extension.
Structs
Constants
Traits
- With
Name - Trait to record information about shared objects, such as their name and
type. See implementation in
crate::future::batch_semaphore::BatchSemaphore, which actually records the name into the schedule, other types should forward calls into their underlying primitive, as inshuttle::sync::Mutex.
Functions
- record_
name_ for_ object - record_
name_ for_ task - record_
random - record_
schedule - record_
semaphore_ acquire_ blocked - record_
semaphore_ acquire_ fast - record_
semaphore_ acquire_ unblocked - record_
semaphore_ closed - record_
semaphore_ created - record_
semaphore_ release - record_
semaphore_ try_ acquire - record_
task_ created - record_
task_ terminated - record_
tick - start_
annotations - stop_
annotations