What to do with what the unfinished tasks of a failed execution leave behind: the functions of
the tasks that never ran, and the futures of the future tasks that are waiting to be polled.
The stacks of a failed execution’s other unfinished tasks are always leaked, and its task-local
values and statics are always dropped. Panics while dropping any of them are ignored, so that
the failure is what gets reported.