Module config

Module config 

Structs

Config
Configuration parameters for Shuttle
UngracefulShutdownConfig
The config to define how to handle ungraceful shutdowns, ie. when the test panics.

Enums

ContinuationFunctionBehavior
What to do with the continuation function when a task panics. Modelled as a non-exhaustive enum because there are a couple of unimplemented behaviors, such as returning the continuation function, or sending the function to a “sacrificial” thread to be dropped
FailurePersistence
Specifies how to persist schedules when a Shuttle test fails
MaxSteps
Specifies an upper bound on the number of steps a single iteration of a Shuttle test can take, and how to react when the bound is reached.

Constants

UNGRACEFUL_SHUTDOWN_CONFIG