What to do with the continuation function when a task panics.
Modelled as a non-exhaustive enum because there are a couple of unimplemented behaviors, such as
returning the continuation function, or sending the function to a “sacrificial” thread to be dropped