Config

Struct Config 

#[non_exhaustive]
pub struct Config { pub stack_size: usize, pub failure_persistence: FailurePersistence, pub max_steps: MaxSteps, pub max_time: Option<Duration>, pub silence_warnings: bool, pub record_steps_in_span: bool, pub ungraceful_shutdown_config: UngracefulShutdownConfig, }
Configuration parameters for Shuttle

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
stack_size: usize

Stack size allocated for each thread

failure_persistence: FailurePersistence

How to persist schedules when a test fails

max_steps: MaxSteps

Maximum number of steps a single iteration of a test can take, and how to react when the limit is reached

max_time: Option<Duration>

Time limit for an entire test. If set, calls to crate::runtime::runner::Runner::run will return when the time limit is exceeded or the Scheduler chooses to stop (e.g., by hitting its maximum number of iterations), whichever comes first. This time limit will not abort a currently running test iteration; the limit is only checked between iterations.

silence_warnings: bool

Whether to silence warnings about Shuttle behaviors that may miss bugs or introduce false positives:

  1. Unsound implementation of atomic may miss bugs
  2. lazy_static values are dropped at the end of an execution
record_steps_in_span: bool

Whether to call the Span::record() method to update the step count (i) of the Span containing the TaskId and the current step count for the given TaskId. If false, this Span will look like this: step{task=1}, and if true, this Span will look something like this: step{task=1 i=3 i=9 i=12}, or, if a Subscriber which overwrites on calls to span.record() is used, something like this:

step{task=1 i=3}
step{task=1 i=9}
step{task=1 i=12}

The reason this is a config option is that the most popular tracing Subscribers, ie tracing_subscriber::fmt, appends to the span on calls to record() (instead of overwriting), which results in traces which are hard to read if the task is scheduled more than a few times. Thus: set record_steps_in_span to true if you want “append behavior”, or if you are using a Subscriber which overwrites on calls to record() and want to display the current step count.

ungraceful_shutdown_config: UngracefulShutdownConfig

The config to define how to handle ungraceful shutdowns, ie. when the test panics.

Implementations

Source

impl Config

pub fn new() -> Self

Create a new default configuration