#[non_exhaustive]pub struct UngracefulShutdownConfig {
pub immediately_return_on_panic: bool,
pub continuation_function_behavior: ContinuationFunctionBehavior,
}Expand description
The config to define how to handle ungraceful shutdowns, ie. when the test panics.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.immediately_return_on_panic: boolBy default (when this is false) when a task panics we will serialize the schedule, then
continue scheduling until the panicking task has fully unwound its stack, and only then return.
This is somewhat wasteful, and also exposes us to more chances of having the entire test abort,
as we are running test code with std::thread::panicking (thus a second panic will be an abort).
Setting this to true will cause scheduling to stop as soon as a task panics. Note that the chance of
an abort (after serializing the schedule) is still present, as we will resume the unwind, and may panic
while calling drop handlers.
continuation_function_behavior: ContinuationFunctionBehaviorWhat to do with the continuation function when it is dropped after a panic.
Implementations