Module future
shuttle_
engine
0.1.0
Module future
Module Items
Modules
Functions
In crate shuttle_
engine
shuttle_engine
Module
future
Modules

batch_
semaphore
A counting semaphore supporting both async and sync operations.
Functions

block_
on
Run a future to completion on the current thread.
yield_
now
Yields execution back to the scheduler.