BatchSemaphore

Struct BatchSemaphore 

pub struct BatchSemaphore { /* private fields */ }
Counting semaphore

Implementations

Source

impl BatchSemaphore

pub fn new(num_permits: usize, fairness: Fairness) -> Self

Creates a new semaphore with the initial number of permits.

pub fn new_with_signature( num_permits: usize, fairness: Fairness, signature: ResourceSignature, ) -> Self

pub const fn const_new(num_permits: usize, fairness: Fairness) -> Self

Creates a new semaphore with the initial number of permits.

pub const fn const_new_with_signature( num_permits: usize, fairness: Fairness, signature: ResourceSignature, ) -> Self

pub fn available_permits(&self) -> usize

Returns the current number of available permits.

pub fn close(&self)

Closes the semaphore. This prevents the semaphore from issuing new permits and notifies all pending waiters.

pub fn close_no_scheduling_point(&self)

Closes the semaphore without invoking thread::switch

pub fn is_closed(&self) -> bool

Returns true iff the semaphore is closed.

pub fn try_acquire(&self, num_permits: usize) -> Result<(), TryAcquireError>

Try to acquire the specified number of permits from the Semaphore. If the permits are available, returns Ok(()) If the semaphore is closed, returns Err(TryAcquireError::Closed) If there aren’t enough permits, returns Err(TryAcquireError::NoPermits)

pub fn acquire(&self, num_permits: usize) -> Acquire<'_>

Acquire the specified number of permits (async API)

pub fn acquire_blocking(&self, num_permits: usize) -> Result<(), AcquireError>

Acquire the specified number of permits (blocking API)

pub fn release(&self, num_permits: usize)

Release num_permits back to the Semaphore

pub fn upgrade( &self, permits_currently_held: usize, permits_to_be_held: usize, ) -> Acquire<'_>

Atomically upgrades from holding permits_currently_held to holding permits_to_be_held. The motivating use case for this is parking_lots RwLockUpgradableReadGuard::ugrade, where we want to be able to go from having a read guard to a write guard while honoring the order of acquires.

This is implemented by first trying to acquire permits_to_be_held (which for the RwLock::upgrade case would never succeed, as the task is holding one permit, and wants to acquire all of them, meaning even with no other tasks it will block on itself), then releaseing permits_currently_held.

This ensures the order of acquires is honored, and prevents the potential deadlock situation which could occur in the naive implementation where permits_to_be_held - permits_currently_held is acquired, and two tasks try to upgrade concurrently (or one upgrade in the presence of a write).

Source

impl BatchSemaphore

pub fn signature(&self) -> &ResourceSignature

Returns a reference to this semaphore’s resource signature.