pub struct BatchSemaphore { /* private fields */ }Expand description
Counting semaphore
Implementations
Sourceimpl BatchSemaphore
impl BatchSemaphore
Sourcepub fn new(num_permits: usize, fairness: Fairness) -> Self
pub fn new(num_permits: usize, fairness: Fairness) -> Self
Creates a new semaphore with the initial number of permits.
pub fn new_with_signature( num_permits: usize, fairness: Fairness, signature: ResourceSignature, ) -> Self
Sourcepub const fn const_new(num_permits: usize, fairness: Fairness) -> Self
pub const fn const_new(num_permits: usize, fairness: Fairness) -> Self
Creates a new semaphore with the initial number of permits.
pub const fn const_new_with_signature( num_permits: usize, fairness: Fairness, signature: ResourceSignature, ) -> Self
Sourcepub fn available_permits(&self) -> usize
pub fn available_permits(&self) -> usize
Returns the current number of available permits.
Sourcepub fn close(&self)
pub fn close(&self)
Closes the semaphore. This prevents the semaphore from issuing new permits and notifies all pending waiters.
Sourcepub fn close_no_scheduling_point(&self)
pub fn close_no_scheduling_point(&self)
Closes the semaphore without invoking thread::switch
Sourcepub fn try_acquire(&self, num_permits: usize) -> Result<(), TryAcquireError>
pub fn try_acquire(&self, num_permits: usize) -> Result<(), TryAcquireError>
Try to acquire the specified number of permits from the Semaphore.
If the permits are available, returns Ok(())
If the semaphore is closed, returns Err(TryAcquireError::Closed)
If there aren’t enough permits, returns Err(TryAcquireError::NoPermits)
Sourcepub fn acquire(&self, num_permits: usize) -> Acquire<'_> ⓘ
pub fn acquire(&self, num_permits: usize) -> Acquire<'_> ⓘ
Acquire the specified number of permits (async API)
Sourcepub fn acquire_blocking(&self, num_permits: usize) -> Result<(), AcquireError>
pub fn acquire_blocking(&self, num_permits: usize) -> Result<(), AcquireError>
Acquire the specified number of permits (blocking API)
Sourcepub fn upgrade(
&self,
permits_currently_held: usize,
permits_to_be_held: usize,
) -> Acquire<'_> ⓘ
pub fn upgrade( &self, permits_currently_held: usize, permits_to_be_held: usize, ) -> Acquire<'_> ⓘ
Atomically upgrades from holding permits_currently_held to holding permits_to_be_held.
The motivating use case for this is parking_lots RwLockUpgradableReadGuard::ugrade, where we want to be able to
go from having a read guard to a write guard while honoring the order of acquires.
This is implemented by first trying to acquire permits_to_be_held (which for the RwLock::upgrade case would never
succeed, as the task is holding one permit, and wants to acquire all of them, meaning even with no other tasks it will
block on itself), then releaseing permits_currently_held.
This ensures the order of acquires is honored, and prevents the potential deadlock situation which could occur in the
naive implementation where permits_to_be_held - permits_currently_held is acquired, and two tasks try to upgrade
concurrently (or one upgrade in the presence of a write).
Sourceimpl BatchSemaphore
impl BatchSemaphore
Sourcepub fn signature(&self) -> &ResourceSignature
pub fn signature(&self) -> &ResourceSignature
Returns a reference to this semaphore’s resource signature.