Structs
- Portfolio
Runner - A
PortfolioRunneris the same as aRunner, except that it can run multiple different schedulers (a “portfolio” of schedulers) in parallel. If any of the schedulers finds a failing execution of the test, the entire run fails. - Runner
- A
Runneris the entry-point for testing concurrent code.