Labels are a way to attach an arbitrary set of values with a task, with the only
constraint being that at most one value of a given type T can be attached at any time,
using get::<T>() to retrieve, and set::<T>(..) to set the value.
Labels behave almost identically to Extensions
in the http crate.
Structs
- Labels
- A collections of assigned Labels