pub struct Labels { /* private fields */ }Expand description
A collections of assigned Labels
Labels can be used to store extra data associated with running tasks.
Implementations
Sourceimpl Labels
impl Labels
Sourcepub fn insert<T: Clone + 'static>(&mut self, val: T) -> Option<T>
pub fn insert<T: Clone + 'static>(&mut self, val: T) -> Option<T>
Insert a type into this Labels.
If a label of this type already existed, it will be returned.
Example
let mut ext = Labels::new();
assert!(ext.insert(5i32).is_none());
assert!(ext.insert(4u8).is_none());
assert_eq!(ext.insert(9i32), Some(5i32));Sourcepub fn get<T: 'static>(&self) -> Option<&T>
pub fn get<T: 'static>(&self) -> Option<&T>
Get a reference to a type previously inserted on this Labels.
Example
let mut ext = Labels::new();
assert!(ext.get::<i32>().is_none());
ext.insert(5i32);
assert_eq!(ext.get::<i32>(), Some(&5i32));Sourcepub fn get_mut<T: 'static>(&mut self) -> Option<&mut T>
pub fn get_mut<T: 'static>(&mut self) -> Option<&mut T>
Get a mutable reference to a type previously inserted on this Labels.
Example
let mut ext = Labels::new();
ext.insert(String::from("Hello"));
ext.get_mut::<String>().unwrap().push_str(" World");
assert_eq!(ext.get::<String>().unwrap(), "Hello World");Sourcepub fn get_or_insert<T: Clone + 'static>(&mut self, value: T) -> &mut T
pub fn get_or_insert<T: Clone + 'static>(&mut self, value: T) -> &mut T
Get a mutable reference to a type, inserting value if not already present on this
Labels.
Example
let mut ext = Labels::new();
*ext.get_or_insert(1i32) += 2;
assert_eq!(*ext.get::<i32>().unwrap(), 3);Sourcepub fn get_or_insert_with<T: Clone + 'static, F: FnOnce() -> T>(
&mut self,
f: F,
) -> &mut T
pub fn get_or_insert_with<T: Clone + 'static, F: FnOnce() -> T>( &mut self, f: F, ) -> &mut T
Get a mutable reference to a type, inserting the value created by f if not already present
on this Labels.
Example
let mut ext = Labels::new();
*ext.get_or_insert_with(|| 1i32) += 2;
assert_eq!(*ext.get::<i32>().unwrap(), 3);Sourcepub fn get_or_insert_default<T: Default + Clone + 'static>(&mut self) -> &mut T
pub fn get_or_insert_default<T: Default + Clone + 'static>(&mut self) -> &mut T
Get a mutable reference to a type, inserting the type’s default value if not already present
on this Labels.
Example
let mut ext = Labels::new();
*ext.get_or_insert_default::<i32>() += 2;
assert_eq!(*ext.get::<i32>().unwrap(), 2);Sourcepub fn remove<T: 'static>(&mut self) -> Option<T>
pub fn remove<T: 'static>(&mut self) -> Option<T>
Remove a type from this Labels.
If a label of this type existed, it will be returned.
Example
let mut ext = Labels::new();
ext.insert(5i32);
assert_eq!(ext.remove::<i32>(), Some(5i32));
assert!(ext.get::<i32>().is_none());Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear all inserted labels
Example
let mut ext = Labels::new();
ext.insert(5i32);
ext.clear();
assert!(ext.get::<i32>().is_none());Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Check whether the label set is empty or not.
Example
let mut ext = Labels::new();
assert!(ext.is_empty());
ext.insert(5i32);
assert!(!ext.is_empty());Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Get the number of Labels available.
Example
let mut ext = Labels::new();
assert_eq!(ext.len(), 0);
ext.insert(5i32);
assert_eq!(ext.len(), 1);Sourcepub fn extend(&mut self, other: Self)
pub fn extend(&mut self, other: Self)
Extends self with another Labels.
If an instance of a specific type exists in both, the one in self is overwritten with the
one from other.
Example
let mut ext_a = Labels::new();
ext_a.insert(8u8);
ext_a.insert(16u16);
let mut ext_b = Labels::new();
ext_b.insert(4u8);
ext_b.insert("hello");
ext_a.extend(ext_b);
assert_eq!(ext_a.len(), 3);
assert_eq!(ext_a.get::<u8>(), Some(&4u8));
assert_eq!(ext_a.get::<u16>(), Some(&16u16));
assert_eq!(ext_a.get::<&'static str>().copied(), Some("hello"));Trait Implementations