pub struct TaskSet { /* private fields */ }Expand description
A TaskSet is a set of TaskIds but implemented efficiently as a BitVec
Implementations
Sourceimpl TaskSet
impl TaskSet
pub const fn new() -> Self
pub fn contains(&self, tid: TaskId) -> bool
pub fn is_empty(&self) -> bool
Sourcepub fn insert(&mut self, tid: TaskId) -> bool
pub fn insert(&mut self, tid: TaskId) -> bool
Add a task to the set. If the set did not have this value present, true is returned. If
the set did have this value present, false is returned.
Sourcepub fn remove(&mut self, tid: TaskId) -> bool
pub fn remove(&mut self, tid: TaskId) -> bool
Removes a value from the set. Returns whether the value was present in the set.
pub fn iter(&self) -> impl Iterator<Item = TaskId> + '_