pub struct Continuation {
pub yielder: *const Yielder<ContinuationInput, ContinuationOutput>,
/* private fields */
}Expand description
A continuation is a green thread that can be resumed and yielded at will. We use it to execute a “thread” from within a Future.
For efficiency, we reuse continuations. The continuation can be provided a new function
to run via initialize. A continuation is only reusable if the previous function it was
executing completed.
Fields
yielder: *const Yielder<ContinuationInput, ContinuationOutput>Implementations
Sourceimpl Continuation
impl Continuation