Core scheduling types: the Scheduler trait, Schedule, and supporting data structures.
Re-exports
pub use crate::runtime::task::Task;pub use crate::runtime::task::TaskId;pub use data::DataSource;pub use data::RandomDataSource;
Modules
- data
- metrics
- serialization
- This module implements a simple serialization scheme for schedules (
Schedule) that tries to produce small printable strings. This is useful for roundtripping schedules in test outputs.
Structs
- Schedule
- A
Scheduledetermines the order in which tasks are to be executed
Enums
Traits
- Scheduler
- A
Scheduleris an oracle that decides the order in which to execute concurrent tasks and the data to return to calls for random values.